==> 0.0.1.tar.gz: lib/web_layer/ble_connectivity_web.dart <==
import 'dart:async';

import 'package:ble_connectivity/ble_connectivity.dart';
import 'package:ble_connectivity/model/fhp_ble_charatereristic.dart';
import 'package:ble_connectivity/model/fhp_ble_device.dart';
import 'package:ble_connectivity/model/scan_properties.dart';
import 'package:ble_connectivity/model/sensor_data_result.dart';
import 'package:flutter/services.dart';

import 'channel_methods.dart';

const MethodChannel _channel = MethodChannel('ble_connectivity');

class BleConnectivityWeb implements BleConnectivity {
  StreamController<ScanEndReason> scanStreamController; // ignore: close_sinks
  Stream<ScanEndReason> get scanStream => scanStreamController.stream;

  @override
  ScanProperties scanProperties;

  @override
  Function(List<FhpBleDevice> sensors) scanResultsCallback;

  @override
  void init() async {
    final result =
        await _channel.invokeMethod<bool>(ChannelMethods.kInitProperties);
  }

  @override
  void disposeListeners() {}

  @override
  void scanResults(Function(List<FhpBleDevice> sensors) result) {
    print('WebBleConnectivity scanResults');
    scanResultsCallback = result;
  }

  @override
  setScanProperties(ScanProperties scanProperties) {
    this.scanProperties = scanProperties;
  }

  @override
  Future<Stream<ScanEndReason>> startScan() async {
    scanStreamController = StreamController.broadcast();

    final result = await _channel.invokeMethod(
      ChannelMethods.kTryConnect,
      <String, Object>{
        'prefix': scanProperties?.sensorPrefixFilter,
        'scanDuration': scanProperties?.scanDuration,
        'characteristics': scanProperties == null
            ? null
            : _characteristicsToMap(scanProperties.characteristics),
      },
    );

    return scanStreamController.stream;
  }

  @override
  stopScan() {
    scanStreamController?.add(ScanEndReason.canceled);
    scanStreamController.close();
    scanStreamController = null;
  }

  @override
  connectWithSensor(
      FhpBleDevice device, Function(BleDeviceState) connectionState) {
    if (device.connectionStatus == BleDeviceState.connected) {
      scanStreamController.add(ScanEndReason.ended);
      scanResultsCallback([device]);
    } else {
      startScan();
    }
  }

  @override
  disconnectWithSensor(FhpBleDevice device) async {
    print('disconnectWithSensor');
    final result = await _channel.invokeMethod(
      ChannelMethods.kDisconnectSensor,
      <String, dynamic>{
        'device': device.name,
      },
    );
  }

  final StreamController<MethodCall> methodStreamController =
      StreamController.broadcast(); // ignore: close_sinks
  Stream<MethodCall> get methodStream => methodStreamController.stream;

  Future<List<Stream<SensorDataResult>>> readSensorCharacteristics(
    FhpBleDevice device,
    Map<String, List<FhpBleCharacteristic>> characteristics,
  ) async {
    print('invoke read characteristics');

    final result = await _channel.invokeMethod(
      ChannelMethods.kReadSensorCharacteristics,
      <String, dynamic>{
        'device': device.name,
        'characteristics': _characteristicsToMap(characteristics),
      },
    );

    List<Stream<SensorDataResult>> characteristicsStreams = [
      methodStream
          .where((event) => event.arguments[0] == device.name)
          .map<SensorDataResult>((event) {
        //print('on characteristics event $event');

        SensorDataResult data = SensorDataResult(
            characteristicUuid: event.arguments[1],
            value: event.arguments[2],
            device: device);
        return data;
      })
    ];

    return characteristicsStreams;
  }

  String _characteristicsToMap(
          Map<String, List<FhpBleCharacteristic>> characteristics) =>
      characteristics
          .map<String, List<String>>((key, value) =>
              MapEntry<String, List<String>>(
                  '\"$key\"', value.map((e) => e.toString()).toList()))
          .toString();

  @override
  Future<List<int>> readCharacteristic(FhpBleDevice device,
      {String serviceUuid, String characteristicUuid}) async {
    final result = await _channel.invokeMethod(
      ChannelMethods.kReadCurrentValues,
      <String, dynamic>{
        'device': device.name,
        'service': serviceUuid,
        'characteristic': characteristicUuid,
      },
    );
  }
}

==> 0.0.2.tar.gz: lib/web_layer/ble_connectivity_web.dart <==
import 'dart:async';

import 'package:ble_connectivity/ble_connectivity_target_platform.dart';
import 'package:ble_connectivity/iotip/iotip_constants.dart';
import 'package:ble_connectivity/model/fhp_ble_charatereristic.dart';
import 'package:ble_connectivity/model/fhp_ble_device.dart';
import 'package:ble_connectivity/model/scan_properties.dart';
import 'package:ble_connectivity/model/sensor_data_result.dart';
import 'package:flutter/services.dart';

import 'channel_methods.dart';

const MethodChannel _channel = MethodChannel('ble_connectivity');

class BleConnectivityWeb implements BleConnectivityTargetPlatform {
  StreamController<ScanEndReason> scanStreamController; // ignore: close_sinks
  Stream<ScanEndReason> get scanStream => scanStreamController.stream;

  @override
  ScanProperties scanProperties;

  @override
  Function(List<FhpBleDevice> sensors) scanResultsCallback;

  @override
  void initScan(ScanProperties scanProperties) async {
    this.scanProperties = scanProperties;
    final result =
        await _channel.invokeMethod<bool>(ChannelMethods.kInitProperties);
  }

  @override
  void disposeListeners() {}

  @override
  void scanResults(Function(List<FhpBleDevice> sensors) result) {
    print('WebBleConnectivity scanResults');
    scanResultsCallback = result;
  }

  @override
  Future<Stream<ScanEndReason>> startScan() async {
    scanStreamController = StreamController.broadcast();

    final result = await _channel.invokeMethod(
      ChannelMethods.kTryConnect,
      <String, Object>{
        'prefix': scanProperties?.sensorPrefixFilter,
        'scanDuration': scanProperties?.scanDuration,
        'characteristics': kIotipCharacteristics,
      },
    );

    return scanStreamController.stream;
  }

  @override
  stopScan() {
    scanStreamController?.add(ScanEndReason.canceled);
    scanStreamController.close();
    scanStreamController = null;
  }

  @override
  connectWithSensor(
      FhpBleDevice device, Function(BleDeviceState) connectionState) {
    if (device.connectionStatus == BleDeviceState.connected) {
      scanStreamController.add(ScanEndReason.ended);
      scanResultsCallback([device]);
    } else {
      startScan();
    }
  }

  @override
  disconnectWithSensor(FhpBleDevice device) async {
    print('disconnectWithSensor');
    final result = await _channel.invokeMethod(
      ChannelMethods.kDisconnectSensor,
      <String, dynamic>{
        'device': device.name,
      },
    );
  }

  final StreamController<MethodCall> methodStreamController =
      StreamController.broadcast(); // ignore: close_sinks
  Stream<MethodCall> get methodStream => methodStreamController.stream;

  Future<List<Stream<SensorDataResult>>> readSensorCharacteristics(
    FhpBleDevice device,
    Map<String, List<FhpBleCharacteristic>> characteristics,
  ) async {
    print('invoke read characteristics');

    final result = await _channel.invokeMethod(
      ChannelMethods.kReadSensorCharacteristics,
      <String, dynamic>{
        'device': device.name,
        'characteristics': _characteristicsToMap(characteristics),
      },
    );

    List<Stream<SensorDataResult>> characteristicsStreams = [
      methodStream
          .where((event) => event.arguments[0] == device.name)
          .map<SensorDataResult>((event) {
        //print('on characteristics event $event');

        SensorDataResult data = SensorDataResult(
            characteristicUuid: event.arguments[1],
            value: event.arguments[2],
            device: device);
        return data;
      })
    ];

    return characteristicsStreams;
  }

  String _characteristicsToMap(
          Map<String, List<FhpBleCharacteristic>> characteristics) =>
      characteristics
          .map<String, List<String>>((key, value) =>
              MapEntry<String, List<String>>(
                  '\"$key\"', value.map((e) => e.toString()).toList()))
          .toString();

  @override
  Future<List<int>> readCharacteristic(FhpBleDevice device,
      {String serviceUuid, String characteristicUuid}) async {
    final result = await _channel.invokeMethod(
      ChannelMethods.kReadCurrentValues,
      <String, dynamic>{
        'device': device.name,
        'service': serviceUuid,
        'characteristic': characteristicUuid,
      },
    );
  }
}
